from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

_4xxx_IEEE = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'4001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4001'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4001\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2', '7', '14', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '14', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '14', '7', '9', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '14', '7', '11']}] }),
        Part(**{ 'name':'4002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4002'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4002\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '7', '1', '14', '3', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '7', '11', '10', '9', '14', '12']}] }),
        Part(**{ 'name':'4006', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4006'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4006\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='DA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q3B',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q4C',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q3A',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DC',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q3D',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q4D',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4008', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4008'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4008\n\n', 'pins':[
            Pin(num='1',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S0',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Cout',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Cin',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4009', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4009'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4009\n\n', 'pins':[
            Pin(num='1',name='Vcc',func=pin_types.PWRIN),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['16', '8', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '8', '4', '5', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8', '7', '6', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['16', '8', '9', '10', '1']},{'label': 'uE', 'num': 5, 'pin_nums': ['16', '12', '8', '11', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['16', '8', '15', '14', '1']}] }),
        Part(**{ 'name':'4010', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4010'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4010\n\n', 'pins':[
            Pin(num='1',name='Vcc',func=pin_types.PWRIN),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '2', '16', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '4', '16', '5', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '6', '16', '7', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9', '16', '1', '10']},{'label': 'uE', 'num': 5, 'pin_nums': ['8', '12', '16', '1', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['8', '16', '15', '1', '14']}] }),
        Part(**{ 'name':'40104', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40104'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40104\n\n', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SRin',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SLin',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='S0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40106', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40106'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40106\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '14', '3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '7', '14', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '7', '14', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '7', '14', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '7', '14', '13']}] }),
        Part(**{ 'name':'4011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4011'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4011\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '14', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '14', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '14', '8', '10', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '14', '11', '13', '7']}] }),
        Part(**{ 'name':'40110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40110'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40110\n\n', 'pins':[
            Pin(num='1',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Qe',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{TE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CKd',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CKu',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4012', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4012'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4012\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '7', '1', '2', '3', '4', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '7', '10', '13', '9', '11', '12']}] }),
        Part(**{ 'name':'4013', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4013'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4013\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Cp',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='R',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Cp',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~{Q}',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='Q',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='S',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '4', '2', '7', '14', '5', '6', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '13', '7', '14', '12', '8', '10', '11']}] }),
        Part(**{ 'name':'4014', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4014'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4014\n\n', 'pins':[
            Pin(num='1',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4015', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4015'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4015\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='10',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='CP',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='Q4',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '5', '3', '16', '10', '8', '6', '9', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '14', '1', '11', '2', '13', '16', '8', '15']}] }),
        Part(**{ 'name':'4016', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4016'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4016\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='I/O',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ON',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='O/I',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='O/I',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='I/O',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='ON',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='ON',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='I/O',func=pin_types.PASSIVE,unit=3),
            Pin(num='9',name='O/I',func=pin_types.PASSIVE,unit=3),
            Pin(num='10',name='O/I',func=pin_types.PASSIVE,unit=4),
            Pin(num='11',name='I/O',func=pin_types.PASSIVE,unit=4),
            Pin(num='12',name='ON',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '13', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '4', '5', '14', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '6', '8', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '11', '14', '10', '12']}] }),
        Part(**{ 'name':'4017', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4017'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4017\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Co',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CP1}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q8',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40174', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40174'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40174\n\n', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='9',name='Ck',func=pin_types.INPUT),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40175', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40175'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40175\n\n', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Ck',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4018', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4018'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4018\n\n', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{Q4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4019', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4019'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4019\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SA',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40192', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40192'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40192\n\n', 'pins':[
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40193'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40193\n\n', 'pins':[
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40194', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40194'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40194\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DSr',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DSl',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4020', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4020'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4020\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Q11',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{CLK}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4021', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4021'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4021\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PL',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4022', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4022'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4022\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Co',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CP1}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CP0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4023', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4023'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4023\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '8', '7', '14', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '5', '14', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '13', '10', '12', '14', '7']}] }),
        Part(**{ 'name':'4024', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4024'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4024\n\n', 'pins':[
            Pin(num='14',name='VDD',func=pin_types.PWRIN),
            Pin(num='7',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='~{CLK}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40240\n\n', 'pins':[
            Pin(num='10',name='Vss',func=pin_types.PWRIN),
            Pin(num='20',name='Vdd',func=pin_types.PWRIN),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['18', '20', '8', '2', '16', '12', '4', '6', '1', '10', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '13', '5', '20', '15', '19', '3', '7', '10', '17', '11']}] }),
        Part(**{ 'name':'40245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40245'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40245\n\n', 'pins':[
            Pin(num='1',name='Dir',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{G}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4025', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4025'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4025\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '1', '7', '9', '2', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '6', '7', '4', '5', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '11', '7', '12', '10', '13']}] }),
        Part(**{ 'name':'4027', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4027'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4027\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='J',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='K',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='R',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='CK',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='S',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '4', '5', '16', '1', '6', '8', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '14', '16', '10', '12', '9', '8', '13', '11']}] }),
        Part(**{ 'name':'4028', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4028'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4028\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='S0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='S7',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='S9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='S5',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='S6',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='S8',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['16', '8']},{'label': 'uA', 'num': 1, 'pin_nums': ['11', '14', '5', '3', '12', '2', '1', '15', '7', '13', '4', '16', '8', '6', '10', '9']}] }),
        Part(**{ 'name':'4029', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4029'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4029\n\n', 'pins':[
            Pin(num='1',name='PL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{TC}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='B/D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4030', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4030'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4030\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '3', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '14', '4', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '14', '7', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '14', '7', '12']}] }),
        Part(**{ 'name':'40373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40373'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40373\n\n', 'pins':[
            Pin(num='1',name='~{EN}',func=pin_types.INPUT),
            Pin(num='10',name='Vss',func=pin_types.PWRIN),
            Pin(num='11',name='ST',func=pin_types.INPUT),
            Pin(num='20',name='Vdd',func=pin_types.PWRIN),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40374'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'CMOS BUFFER 3State', 'description':'', 'datasheet':'https://www.digchip.com/datasheets/download_datasheet.php?id=369790&part-number=HEF40374BDB', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40374\n\nCMOS BUFFER 3State', 'pins':[
            Pin(num='1',name='~{E}',func=pin_types.INPUT),
            Pin(num='10',name='Vss',func=pin_types.PWRIN),
            Pin(num='11',name='Ck',func=pin_types.INPUT),
            Pin(num='20',name='Vdd',func=pin_types.PWRIN),
            Pin(num='12',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4040', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4040'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4040\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q11',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4041', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4041'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4041\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '2', '1', '7', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '6', '4', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '14', '7', '9', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '11', '13', '7', '12']}] }),
        Part(**{ 'name':'4042', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4042'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4042\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='E0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4043', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4043'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4043\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4044', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4044'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4044\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4046', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4046'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4046\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='PCP',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SFout',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC2',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='SigIn',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='ZOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PC1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RefIn',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='FOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Inh',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='C2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCOin',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4048', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4048'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4048\n\n', 'pins':[
            Pin(num='1',name='J',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Ka',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Ex',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Kb',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Kc',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4049', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4049'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4049\n\n', 'pins':[
            Pin(num='1',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '4', '1', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '6', '1', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9', '1', '10']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '12', '8', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['8', '1', '14', '15']}] }),
        Part(**{ 'name':'4050', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4050'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4050\n\n', 'pins':[
            Pin(num='1',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '8', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '4', '8', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '6', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['10', '8', '9', '1']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '8', '11', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['14', '8', '1', '15']}] }),
        Part(**{ 'name':'4051', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4051'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4051\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='X4',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='X3',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='X0',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='X1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='X2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='X6',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='X',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X7',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='X5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='C',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4052', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4052'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4052\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='Y0',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='X3',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='X0',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='X',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='X1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='X2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Y2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Y',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Y3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Y1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4053', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4053'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4053\n\n', 'pins':[
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='8',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='Y1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='X0',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='X1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='X',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Y',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Y0',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Z0',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Z',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Z0',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='C',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4060', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4060'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'binary counter oscillator', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/m74hc4060.pdf', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4060\n\nbinary counter oscillator', 'pins':[
            Pin(num='1',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Î¦0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Î¦1}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q14',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Î¦0}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4068', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4068'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmos nand and 8-input', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd4068b.pdf', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4068\n\ncmos nand and 8-input', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='K',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='J',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='E',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4069', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4069'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4069\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '14', '7', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6', '7', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '14', '7', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '7', '11', '14']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '14', '7', '13']}] }),
        Part(**{ 'name':'4070', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4070'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4070\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '3', '14', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '5', '6', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '10', '8', '14', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '13', '14', '11', '12']}] }),
        Part(**{ 'name':'4071', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4071'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4071\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3', '14', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '14', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '14', '7', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '13', '11', '14', '7']}] }),
        Part(**{ 'name':'4072', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4072'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4072\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '3', '14', '12', '1', '4', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '10', '13', '14', '11', '9', '12']}] }),
        Part(**{ 'name':'4073', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4073'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4073\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '14', '9', '1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '14', '4', '7', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '11', '13', '10', '12', '7']}] }),
        Part(**{ 'name':'4075', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4075'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4075\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '14', '8', '1', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '14', '3', '6', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '7', '13', '11', '14', '12']}] }),
        Part(**{ 'name':'4077', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4077'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4077\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '14', '1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '14', '4', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '7', '14', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '14', '11', '13', '12']}] }),
        Part(**{ 'name':'4078', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4078'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmos', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/cd4078b.pdf', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4078\n\ncmos', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4081', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4081'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4081\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1', '14', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '4', '14', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '7', '8', '14', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '7', '11', '13', '14']}] }),
        Part(**{ 'name':'4082', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4082'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4082\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '14', '2', '5', '1', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '13', '14', '11', '9', '12', '7']}] }),
        Part(**{ 'name':'4093', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4093'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4093\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2', '14', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '7', '4', '14', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14', '9', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '7', '12', '14']}] }),
        Part(**{ 'name':'4095', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4095'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4095\n\n', 'pins':[
            Pin(num='10',name='K2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='J2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='J3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='K3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4096', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4096'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4096\n\n', 'pins':[
            Pin(num='10',name='K2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='J1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='J2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{J3}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{K3}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4099', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4099'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4099\n\n', 'pins':[
            Pin(num='1',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='WR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4104', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4104'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4104\n\n', 'pins':[
            Pin(num='1',name='Vddo',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vddi',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4160'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4160\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4161', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4161'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4161\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4162', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4162'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4162\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4163', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4163'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4163\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4174', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4174'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4174\n\n', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='9',name='Ck',func=pin_types.INPUT),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4175', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4175'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4175\n\n', 'pins':[
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Ck',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4502', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4502'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4502\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{V1}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{Y6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Y4}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4504', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4504'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmos, level converter', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cd4504b.pdf', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4504\n\ncmos, level converter', 'pins':[
            Pin(num='1',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4507', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4507'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4507\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '3', '1', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '14', '6', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '7', '10', '8', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '12', '11', '14', '13']}] }),
        Part(**{ 'name':'4508', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4508'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4508\n\n', 'pins':[
            Pin(num='12',name='Vss',func=pin_types.PWRIN),
            Pin(num='24',name='Vdd',func=pin_types.PWRIN),
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='ST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='ST',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='D0',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='18',name='D1',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='20',name='D2',func=pin_types.INPUT,unit=2),
            Pin(num='21',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='22',name='D3',func=pin_types.INPUT,unit=2),
            Pin(num='23',name='Q3',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['11', '1', '7', '9', '4', '3', '12', '2', '10', '5', '24', '8', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['21', '19', '23', '14', '16', '15', '17', '18', '20', '22', '24', '12', '13']}] }),
        Part(**{ 'name':'4510', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4510'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4510\n\n', 'pins':[
            Pin(num='1',name='PE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{Cin}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Cout}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RST',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4511'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4511\n\n', 'pins':[
            Pin(num='1',name='DB',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DC',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{EL}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DD',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DA',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Qe',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4512'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4512\n\n', 'pins':[
            Pin(num='1',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='I7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4514', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4514'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4514\n\n', 'pins':[
            Pin(num='1',name='EL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q15',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q14',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Q11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4515', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4515'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4515\n\n', 'pins':[
            Pin(num='1',name='EL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='Q13',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q12',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q15',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Q14',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='Q9',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Q8',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Q11',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Q10',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q6',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q5',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4518', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4518'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4518\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CP1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP1',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='Q3',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='CP0',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '16', '4', '2', '7', '3', '8', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '9', '10', '14', '12', '11', '15', '8', '13']}] }),
        Part(**{ 'name':'4520', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4520'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4520\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='CP0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CP1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP1',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='Q3',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='MR',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='CP0',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '8', '2', '7', '16', '5', '3', '1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '16', '11', '13', '15', '12', '10', '9', '14']}] }),
        Part(**{ 'name':'4529', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4529'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4529\n\n', 'pins':[
            Pin(num='1',name='STX',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='W',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='Y3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Y2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Y1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Y0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='STY',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='X0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='X3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Z',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4530', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4530'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4530\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='Y',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '16', '6', '8', '1', '5', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '12', '9', '14', '10', '16', '8', '15', '11']}] }),
        Part(**{ 'name':'4538', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4538'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4538\n\n', 'pins':[
            Pin(num='1',name='CX',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Rx',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='R',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='Rx',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='CX',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=2),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '7', '1', '4', '5', '3', '2', '8', '16']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '15', '14', '16', '13', '8', '12', '9', '11']}] }),
        Part(**{ 'name':'4539', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4539'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4539\n\n', 'pins':[
            Pin(num='14',name='S0',func=pin_types.INPUT),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='2',name='S1',func=pin_types.INPUT),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '7', '1', '2', '5', '16', '8', '3', '6', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '13', '9', '2', '16', '12', '10', '15', '8', '14']}] }),
        Part(**{ 'name':'4543', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4543'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4543\n\n', 'pins':[
            Pin(num='1',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qe',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DC',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PH',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Qa',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4555', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4555'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4555\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='A0',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '16', '5', '1', '6', '2', '4', '8', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '12', '10', '15', '11', '13', '8', '9', '14']}] }),
        Part(**{ 'name':'4556', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4556'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4556\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{Q2}',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='~{Q1}',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='~{Q0}',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='A1',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='A0',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='~{Q3}',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '5', '1', '8', '6', '16', '4', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '14', '9', '13', '8', '12', '10', '15', '16']}] }),
        Part(**{ 'name':'4585', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4585'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4585\n\n', 'pins':[
            Pin(num='16',name='Vdd',func=pin_types.PWRIN),
            Pin(num='8',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qa<b',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qa>b',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Qa=b',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Ia>b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Ia<b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Ia=b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='B1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40160'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40160\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40161', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40161'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40161\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40162', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40162'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40162\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40163', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40163'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40163\n\n', 'pins':[
            Pin(num='1',name='MR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CET',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='TC',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CEP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'40244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'40244'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n40244\n\n', 'pins':[
            Pin(num='10',name='Vss',func=pin_types.PWRIN),
            Pin(num='20',name='Vdd',func=pin_types.PWRIN),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '10', '2', '4', '12', '16', '6', '1', '14', '20', '18']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '10', '3', '7', '19', '17', '11', '13', '5', '9', '20']}] }),
        Part(**{ 'name':'4066', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4066'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4066\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='I/O',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ON',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='O/I',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='O/I',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='I/O',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='ON',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='ON',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='I/O',func=pin_types.PASSIVE,unit=3),
            Pin(num='9',name='O/I',func=pin_types.PASSIVE,unit=3),
            Pin(num='10',name='O/I',func=pin_types.PASSIVE,unit=4),
            Pin(num='11',name='I/O',func=pin_types.PASSIVE,unit=4),
            Pin(num='12',name='ON',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '13', '2', '14', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '14', '4', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '9', '14', '6', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['10', '12', '11', '14', '7']}] }),
        Part(**{ 'name':'4528', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4528'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4528\n\n', 'pins':[
            Pin(num='1',name='CX',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Rx',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='R',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='Rx',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='CX',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=2),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='Q',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '16', '7', '8', '5', '2', '4', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '10', '13', '9', '16', '11', '8', '14', '12']}] }),
        Part(**{ 'name':'4584', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4584'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/4xxx_IEEE.kicad_sym\n4584\n\n', 'pins':[
            Pin(num='14',name='Vdd',func=pin_types.PWRIN),
            Pin(num='7',name='Vss',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '7', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '14', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '7', '5', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '7', '14', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '7', '14', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '7', '14', '13']}] })])